package edu.nyu.sps.hello;

import android.content.Context;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.text.method.ScrollingMovementMethod;
import android.util.DisplayMetrics;
import android.view.Display;
import android.view.Surface;
import android.view.WindowManager;
import android.widget.TextView;

import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.text.DateFormat;
import java.util.Date;
import java.util.Enumeration;

public class MainActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //Version numbers.
        String s = "SDK version: " + Build.VERSION.SDK_INT + "\n"
                + "Android release: " + Build.VERSION.RELEASE + "\n";

        //Screen dimensions.  Unicode 00D7 is the "by" or "times" symbol.
        WindowManager windowManager = (WindowManager) getSystemService(Context.WINDOW_SERVICE);
        Display defaultDisplay = windowManager.getDefaultDisplay();
        DisplayMetrics displayMetrics = new DisplayMetrics(); //Create an empty DisplayMetrics.
        defaultDisplay.getMetrics(displayMetrics);   //Put values into the DisplayMetrics.

        s += "Screen dimensions in pixels: "
                + displayMetrics.widthPixels + " \u00D7 " + displayMetrics.heightPixels + "\n";

        //Pixels per inch.
        s += "Pixels per inch (horizontally): " + displayMetrics.xdpi + "\n";
        s += "Pixels per inch (vertically): " + displayMetrics.ydpi + "\n";
        s += "Screen dimensions in inches: "
                + displayMetrics.widthPixels / displayMetrics.xdpi + " \u00D7 "
                + displayMetrics.heightPixels / displayMetrics.ydpi + "\n";

        //Density.
        s += "Pixels per dp: " + displayMetrics.density + "\n";
        if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_DEFAULT) {
            s += "DisplayMetrics.DENSITY_DEFAULT\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_LOW) {
            s += "DisplayMetrics.DENSITY_LOW\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_MEDIUM) {
            s += "DisplayMetrics.DENSITY_MEDIUM\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_HIGH) {
            s += "DisplayMetrics.DENSITY_HIGH\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_TV) {
            s += "DisplayMetrics.DENSITY_TV\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_280) {
            s += "DisplayMetrics.DENSITY_280\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_360) {
            s += "DisplayMetrics.DENSITY_360\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_XHIGH) {
            s += "DisplayMetrics.DENSITY_XHIGH\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_400) {
            s += "DisplayMetrics.DENSITY_400\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_420) {
            s += "DisplayMetrics.DENSITY_420\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_XXHIGH) {
            s += "DisplayMetrics.DENSITY_XXHIGH\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_560) {
            s += "DisplayMetrics.DENSITY_560\n";
        } else if (displayMetrics.densityDpi == DisplayMetrics.DENSITY_XXXHIGH) {
            s += "DisplayMetrics.DENSITY_XXXHIGH\n";
        } else {
            s += "Unknown DisplayMetrics.DENSITY_\n";
        }

        //Device orientation
        Resources resources = getResources();
        Configuration configuration = resources.getConfiguration();
        if (configuration.orientation == Configuration.ORIENTATION_PORTRAIT) {
            s += "Configuration.ORIENTATION_PORTRAIT\n";
        } else if (configuration.orientation == Configuration.ORIENTATION_LANDSCAPE) {
            s += "Configuration.ORIENTATION_LANDSCAPE\n";
        } else {
            s += "Unknown Configuration.ORIENTATION_\n";
        }

        //Rotation
        int rotation = defaultDisplay.getRotation();
        if (rotation == Surface.ROTATION_0) {
            s += "Surface.ROTATION_0\n";
        } else if (rotation == Surface.ROTATION_90) {
            s += "Surface.ROTATION_90\n";
        } else if (rotation == Surface.ROTATION_180) {
            s += "Surface.ROTATION_180\n";
        } else if (rotation == Surface.ROTATION_270) {
            s += "Surface.ROTATION_270\n";
        } else {
            s += "Unknown Surface.ROTATION_\n";
        }

        //Name of app.
        s += "App name: " + resources.getString(R.string.app_name) + "\n";

        //Process id number and user id number.
        int pid = android.os.Process.myPid();
        s += "App Process ID: " + pid + "\n";
        int uid = android.os.Process.myUid();
        s += "App User ID: " + uid + "\n";

        //Current thread.
        Thread currentThread = Thread.currentThread();
        s += "ID of current thread: " + currentThread.getId() + "\n";
        s += "Name of current thread: " + currentThread.getName() + "\n";

        //Date and time.
        Date date = new Date();	//time as well as date
        DateFormat dateFormat = DateFormat.getDateTimeInstance();
        s += dateFormat.format(date) + "\n\n";

        //Check for Internet connectivity.
        ConnectivityManager connectivityManager =
                (ConnectivityManager)getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo networkInfo = connectivityManager.getActiveNetworkInfo();
        s += networkInfo + "\n\n";

        //IP address(es)
        try {
            for (Enumeration<NetworkInterface> ei = NetworkInterface.getNetworkInterfaces();
                 ei.hasMoreElements();) {
                NetworkInterface networkInterface = ei.nextElement();
                s += "Name of network interface: " + networkInterface.getDisplayName() + "\n";

                for (Enumeration<InetAddress> ea = networkInterface.getInetAddresses();
                     ea.hasMoreElements();) {
                    InetAddress inetAddress = ea.nextElement();
                    s += "   IP address: " + inetAddress.getHostAddress() + "\n";
                }
            }
        } catch (SocketException socketException) {
            s += socketException.getMessage() + "\n";
        }

        TextView textView = (TextView)findViewById(R.id.textView);
        textView.setMovementMethod(new ScrollingMovementMethod());
        textView.setText(s);
    }
}
